// TheFDCT.java

import java.lang.Math;


class TheFDCT {
  TheFrame parent;  
  
  double[][] C,Ct;           // C  <= Cosine Transform Matrix, Ct <= Transposed C
  int N=8;                   // Block-Size
  int[][] rpixel, bpixel, gpixel, any_pixel;  // stores RGB-Pixelblocks
  int[][] rout, bout, gout, any_out;  // output values


public TheFDCT ( TheFrame parent ) {
    
    this.parent = parent;
    
    C =new double[N][N];
    Ct=new double[N][N];
    rout = new int[8][8];
    bout = new int[8][8];
    gout = new int[8][8];
    rpixel = new int[8][8]; 
    bpixel = new int[8][8];
    gpixel = new int[8][8];
    
    for (int i = 0; i < N; i++) {
      C [0][i] = 1.0/Math.sqrt(N);
      Ct[i][0] = C[0][i];
    }
    for(int i = 1; i < N; i++)
    for(int j = 0; j < N; j++) {
		C [i][j]=Math.sqrt(2.0/N)*Math.cos((2*j+1)*i*Math.PI/(2.0*N));
		Ct[j][i]=C[i][j];      
    }     
    
} // end of constructor


/*
public double[][] forwardDCT(double[][] in) // isf = input sample field
{	
	double[][] out = new double[8][8];		// cf = coefficients field
	double Cu = 0, Cv = 0;
	double sumx, sumy, sumxy, cosu, cosv;
	double pi = Math.PI;
	double sqrt2 = Math.sqrt(2);	
		
	for (int v = 0; v < 8; v++)
	for (int u = 0; u < 8; u++)
	{
		if (v == 0) { Cv = 1/sqrt2; } else { Cv = 1; }
		if (u == 0) { Cu = 1/sqrt2; } else { Cu = 1; }
		
		sumxy = 0;
		for (int y = 0; y < 8; y++)
		{				
			for (int x = 0; x < 8; x++)
			{
				cosu = Math.cos( (2*x+1)*u*pi/16 );
				cosv = Math.cos( (2*y+1)*v*pi/16 );
				sumxy += (in[y][x]-128)*cosu*cosv; // -128 -> zero shift
			} // end of for (int x ...
			
		} // end of for (int y ...
			
		//out[v][u] = (int)Math.round( sumxy*0.25*Cu*Cv ); // 0.25 = 0.5*0.5  ;-)
		out[v][u] = sumxy*0.25*Cu*Cv;
						
	} // end of outer double sum
		
	return out;
		
} // end of public int[][] transformation( ... )
*/


public double[][] forwardDCT(double[][] in) {
	
    double [][] output = new double[N][N];
    double[][] d  = new double[N][N];
    double out;
    
    
    for(int i = 0; i < N; i++)
    for(int j = 0; j < N; j++) {
		d[i][j]=0.0;
		for(int k = 0;k < N;k++) { d[i][j] += ((in[i][k]-128)*Ct[k][j]); }		
    }
    
    for(int i = 0; i < N; i++) 
    for(int j = 0; j < N; j++) {
		out = 0.0;
		for(int k = 0; k < N; k++) { out += C[i][k]*d[k][j];}
		output[i][j] = out;
    }        
    return(output);
}// end of forwardDCT


/*
final double[][] getYValues( int[][] rpixel, int[][] gpixel, int[][] bpixel ) {
	
    double [][] ypixel = new double[8][8];
    
    for (int i=0;i<8;i++)
    for (int j=0;j<8;j++) {	
		ypixel[i][j] = (0.3*rpixel[i][j]+0.59*gpixel[i][j]+0.11* bpixel[i][j]);
    }    
    ypixel = forwardDCT(ypixel);
    return ypixel;
}
*/

} // end of class









