// TheFrame.java

import java.applet.*;
import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import java.io.*;
import java.net.*;
import java.lang.Math;

public class TheFrame extends JFrame
{
	URL codebase;	
	AppletContext ac;
		
	TheGUI gui; // the Graphical User Interface (GUI)	
	TheEventHandler evth; // reactions to actions in the gui
	TheFDCT fdct;
	TheIDCT idct;
	TheQuantizer quantizer;
	SmallDCT sdct;
	BigDCT bdct;
	YuvRGBConverter converter;
	ImageLoader imageloader;
	
	InputImage ii;
	OutputImage oi;
		
	GridBagConstraints gbc = new GridBagConstraints();
	Toolkit tk = Toolkit.getDefaultToolkit();
	Dimension preferredFrameDim = new Dimension(640,480); //648,545
	Dimension screenDim = tk.getScreenSize();
	Dimension frameDim;
	int screenheight = screenDim.height;
	int screenwidth = screenDim.width;
			
public TheFrame(URL codebase, final AppletContext ac) {
	
	this.codebase = codebase;
	this.ac = ac;
			
	// get the imageloader	
	imageloader = new ImageLoader(codebase,ac);
				
	// on ms-windows systems you can close a window with the little x in its top right corner
	// but first you have to activate this option
	addWindowListener(new WindowAdapter()
		{ public void windowClosing(WindowEvent e) { TheApplet.activ = false;dispose(); }});
			
	// sets the standard laf manager
	try{	UIManager.setLookAndFeel("javax.swing.plaf.metal.MetalLookAndFeel");
		SwingUtilities.updateComponentTreeUI(this);
		validate();   }
	catch(Exception e)
	{JOptionPane.showMessageDialog(null,"LookAndFeel switch not successful!\nSwitching to JDK default.","Error",JOptionPane.ERROR_MESSAGE);}
	
	setTitle("Visualizing the idea of JPEG compression: Discrete Cosine Transform & Quantiziation");
	setResizable(false);
	
	// standard screensize is stored in 'preferredFrameDim', but if the user's actuall screenresolution
	// is smaller then this, the frame will be only as big as the smaller screensize
	if (screenwidth < preferredFrameDim.width)
	{ 			
		frameDim = new Dimension(screenwidth,screenheight);			
	}
	else    
	{ 					
		frameDim = preferredFrameDim;
		//if the users screenresolution is greater than 640x480 the frame is displayed centered 
		setLocation((screenwidth-preferredFrameDim.width)/2,(screenheight-preferredFrameDim.height)/2);
	}
		
	setSize(frameDim);	
		
	ii = new InputImage(this);
	oi = new OutputImage(this);

	converter = new YuvRGBConverter();           // YUV-RGB Converter
	fdct = new TheFDCT(this);                    // DCT
	idct = new TheIDCT(this);                    // IDCT
	quantizer = new TheQuantizer(this);          // quantization
	sdct = new SmallDCT( this );                 // smallDCT (nur vergoesserung)
	bdct = new BigDCT( this );                   // bigDCT (komplettes bild)
	
	evth = new TheEventHandler(this);            // the eventhandler
	gui = new TheGUI(this);                      // the GUI
			
	sdct.start();
	bdct.start();	
	
	new Thread() { public void run() {
            		try {Thread.sleep(2000); ac.showStatus(""); } catch (InterruptedException ie){} 
            	     }}.start();
	
} // end of public Frame Constructor


public static void matrixPrint(double[][] m) {
	
String s;
	System.out.println();
	System.out.println("*************double************");
	for (int y = 0; y < 8; y++) {
		s="";
		for (int x = 0; x < 8; x++) { s+=(m[x][y])+", "; }
		System.out.println(s);	
	} // y	
	System.out.println("*******************************");
	
} // matrixPrint( double )


public static void matrixPrint(int[][] m) {
	
String s;
	System.out.println("*************int***************");
	for (int y = 0; y < 8; y++) {
		s="";
		for (int x = 0; x < 8; x++) { s+=(m[x][y])+", "; }
		System.out.println(s);	
	} // y	
	System.out.println("*******************************");	
	
} // matrixPrint( int )

	
} // end of class