//YuvRGBConverter.java

import java.lang.Math;

class YuvRGBConverter {

// RGB to Yuv matrix
final private double[][] mR2Y = new double[][] { 
		{ 0.299, 0.587, 0.114},
		{-0.148,-0.289, 0.437},
		{ 0.615,-0.515,-0.100} };
// Yuv to RGB matrix		
final private double[][] mY2R = new double[][] { 
		{ 1.000, 0.000, 1.140},
		{ 1.000,-0.395,-0.581},
		{ 1.000, 2.032, 0.000} };
		
private double[][] Ymatrix = new double[8][8];
private double[][] Umatrix = new double[8][8];
private double[][] Vmatrix = new double[8][8];

private int[][] Rmatrix = new int[8][8];
private int[][] Gmatrix = new int[8][8];
private int[][] Bmatrix = new int[8][8];
		
YuvRGBConverter() {
	
} // end of constructor


/***************** RGB to YUV ***************************/

public double[][] RGB2Yuv_Y(int[][] Rin, int[][] Gin, int[][] Bin) {

	double[][] out = new double[8][8];

	for (int y = 0; y < 8; y++)
	for (int x = 0; x < 8; x++) {		
		out[y][x] = mR2Y[0][0]*Rin[y][x] + mR2Y[0][1]*Gin[y][x] + mR2Y[0][2]*Bin[y][x];
	} //end of loop	
	
return out;
}


public double[][] RGB2Yuv_U(int[][] Rin, int[][] Gin, int[][] Bin) {

	double[][] out = new double[8][8];

	for (int y = 0; y < 8; y++)
	for (int x = 0; x < 8; x++) {		
		out[y][x] = mR2Y[1][0]*Rin[y][x] + mR2Y[1][1]*Gin[y][x] + mR2Y[1][2]*Bin[y][x];
	} //end of loop	
	
return out;
}


public double[][] RGB2Yuv_V(int[][] Rin, int[][] Gin, int[][] Bin) {

	double[][] out = new double[8][8];

	for (int y = 0; y < 8; y++)
	for (int x = 0; x < 8; x++) {		
		out[y][x] = mR2Y[2][0]*Rin[y][x] + mR2Y[2][1]*Gin[y][x] + mR2Y[2][2]*Bin[y][x];
	} //end of loop	
	
return out;
}


/***************** YUV to RGB ***************************/

public int[][] Yuv2RGB_R(double[][] Yin, double[][] Uin, double[][] Vin) {
	
	int[][] out = new int[8][8];

	for (int y = 0; y < 8; y++)
	for (int x = 0; x < 8; x++) {	
		out[y][x] = (int)Math.round(mY2R[0][0]*Yin[y][x] + mY2R[0][1]*Uin[y][x] + mY2R[0][2]*Vin[y][x]);	
	} //end of loop	
	
return out;		
}


public int[][] Yuv2RGB_G(double[][] Yin, double[][] Uin, double[][] Vin) {
	
	int[][] out = new int[8][8];

	for (int y = 0; y < 8; y++)
	for (int x = 0; x < 8; x++) {		
		out[y][x] = (int)Math.round(mY2R[1][0]*Yin[y][x] + mY2R[1][1]*Uin[y][x] + mY2R[1][2]*Vin[y][x]);			
	} //end of loop
	
return out;		
}


public int[][] Yuv2RGB_B(double[][] Yin, double[][] Uin, double[][] Vin) {
	
	int[][] out = new int[8][8];

	for (int y = 0; y < 8; y++)
	for (int x = 0; x < 8; x++) {		
		out[y][x] = (int)Math.round(mY2R[2][0]*Yin[y][x] + mY2R[2][1]*Uin[y][x] + mY2R[2][2]*Vin[y][x]);	
	} //end of loop
	
return out;
}
	
} // end of class